@@ -1,7 +1,7 @@
 /* Emacs style mode select   -*- C++ -*- 
  *-----------------------------------------------------------------------------
  *
- * $Id: am_map.c,v 1.19 2000/03/14 18:59:38 cph Exp $
+ * $Id: am_map.c,v 1.17 1999/10/12 13:01:09 cphipps Exp $
  *
  *  LxDoom, a Doom port for Linux/Unix
  *  based on BOOM, a modified and improved DOOM engine
@@ -31,7 +31,7 @@
  */
 
 static const char rcsid[] =
-  "$Id: am_map.c,v 1.19 2000/03/14 18:59:38 cph Exp $";
+  "$Id: am_map.c,v 1.17 1999/10/12 13:01:09 cphipps Exp $";
 
 #include "doomstat.h"
 #include "st_stuff.h"
@@ -533,13 +533,14 @@ void AM_clearMarks(void)
 // Affects automap's global variables
 //
 // CPhipps - get status bar height from status bar code
+extern int screenSize;
 void AM_LevelInit(void)
 {
   leveljuststarted = 0;
 
   f_x = f_y = 0;
   f_w = SCREENWIDTH;           // killough 2/7/98: get rid of finit_ vars
-  f_h = SCREENHEIGHT-st_height;// to allow runtime setting of width/height
+  f_h = SCREENHEIGHT - (screenSize < 8 ? st_height : 0);// to allow runtime setting of width/height
 
   AM_findMinMaxBoundaries();
   scale_mtof = FixedDiv(min_scale_mtof, (int) (0.7*FRACUNIT));
@@ -712,7 +713,7 @@ boolean AM_Responder
     else if (ch == key_map_mark)
     {
       // Ty 03/27/98 - *not* externalized     
-      snprintf(buffer, sizeof(buffer), "%s %d", s_AMSTR_MARKEDSPOT, markpointnum);  
+      sprintf(buffer, "%s %d", s_AMSTR_MARKEDSPOT, markpointnum);  
       plr->message = buffer;
       AM_addMark();
     }
@@ -1637,15 +1638,10 @@ void AM_drawMarks(void)
     {
       int w = 5;
       int h = 6;
-      int fx = markpoints[i].x;
-      int fy = markpoints[i].y;
+      int fx = CXMTOF(markpoints[i].x);
+      int fy = CYMTOF(markpoints[i].y);
       int j = i;
 
-      if (automapmode & am_rotate)
-        AM_rotate(&fx, &fy, -plr->mo->angle+ANG90, plr->mo->x, plr->mo->y);
-
-      fx = CXMTOF(fx); fy = CYMTOF(fy);
-
       do
       {
         int d = j % 10;
@@ -1654,8 +1650,8 @@ void AM_drawMarks(void)
 
         if (fx >= f_x && fx < f_w - w && fy >= f_y && fy < f_h - h) {
 	  // cph - construct patch name and draw marker
-	  char namebuf[] = { 'A', 'M', 'M', 'N', 'U', 'M', '0'+d, 0 };
-	  
+	  char namebuf[9];
+	  sprintf(namebuf, "AMMNUM%d", /* i */ d); // cph - Fix blunder, we want the digit here
           V_DrawNamePatch(fx, fy, FB, namebuf, NULL, VPT_NONE);
 	}
         fx -= w-1;          // killough 2/22/98: 1 space backwards
@@ -1710,12 +1706,6 @@ void AM_Drawer (void)
 //----------------------------------------------------------------------------
 //
 // $Log: am_map.c,v $
-// Revision 1.19  2000/03/14 18:59:38  cph
-// Clean sprintfs out
-//
-// Revision 1.18  1999/12/22 19:46:40  cphipps
-// Fix rotation of automap marks
-//
 // Revision 1.17  1999/10/12 13:01:09  cphipps
 // Changed header to GPL
 //
