@@ -1,7 +1,7 @@
 /* Emacs style mode select   -*- C++ -*- 
  *-----------------------------------------------------------------------------
  *
- * $Id: g_game.c,v 1.36 2000/03/17 20:50:30 cph Exp $
+ * $Id: g_game.c,v 1.33 1999/10/17 09:35:15 cphipps Exp $
  *
  *  LxDoom, a Doom port for Linux/Unix
  *  based on BOOM, a modified and improved DOOM engine
@@ -34,7 +34,7 @@
  */
 
 static const char
-rcsid[] = "$Id: g_game.c,v 1.36 2000/03/17 20:50:30 cph Exp $";
+rcsid[] = "$Id: g_game.c,v 1.33 1999/10/17 09:35:15 cphipps Exp $";
 
 #include <stdarg.h>
 
@@ -64,9 +64,8 @@ rcsid[] = "$Id: g_game.c,v 1.36 2000/03/17 20:50:30 cph Exp $";
 #include "d_deh.h"              // Ty 3/27/98 deh declarations
 #include "p_inter.h"
 #include "g_game.h"
-#include "lprintf.h"
-#include "i_main.h"
 #include "i_system.h"
+#include "lprintf.h"
 
 #define SAVEGAMESIZE  0x20000
 #define SAVESTRINGSIZE  24
@@ -256,8 +255,11 @@ void G_BuildTiccmd(ticcmd_t* cmd)
   int forward;
   int side;
   int newweapon;                                          // phares
-  /* cphipps - remove needless I_BaseTiccmd call, just set the ticcmd to zero */
-  memset(cmd,0,sizeof*cmd);
+  ticcmd_t *base;
+
+  base = I_BaseTiccmd();   // empty, or external driver
+  memcpy(cmd, base, sizeof *cmd);
+
   cmd->consistancy = consistancy[consoleplayer][maketic%BACKUPTICS];
 
   strafe = gamekeydown[key_strafe] || mousebuttons[mousebstrafe]
@@ -463,12 +465,12 @@ void G_BuildTiccmd(ticcmd_t* cmd)
         dclicks2 = 0;
         dclickstate2 = 0;
       }
-  mousey = (mousey > 0) ? mousey : mousey / 6; /* mead desense backward moves. */
+
   forward += mousey;
   if (strafe)
-    side += mousex / 4;       /* mead  Don't want to strafe as fast as turns.*/
+    side += mousex*2;
   else
-    cmd->angleturn -= mousex; /* mead now have enough dynamic range 2-10-00 */
+    cmd->angleturn -= mousex*0x8;
 
   mousex = mousey = 0;
 
@@ -616,6 +618,7 @@ boolean G_Responder (event_t* ev)
 {
   // allow spy mode changes even during the demo
   // killough 2/22/98: even during DM demo
+  
 
   if (gamestate == GS_LEVEL && ev->type == ev_keydown
       && ev->data1 == key_spy /* phares */ &&
@@ -645,6 +648,8 @@ boolean G_Responder (event_t* ev)
       return false;
     }
 
+  if (ev->data1 == 13) gamekeydown[13] = true;
+  
   if (gamestate == GS_LEVEL)
     {
       if (HU_Responder (ev))
@@ -661,6 +666,7 @@ boolean G_Responder (event_t* ev)
         return true;  // finale ate the event
     }
 
+
   switch (ev->type)
     {
     case ev_keydown:
@@ -669,7 +675,9 @@ boolean G_Responder (event_t* ev)
           special_event = BT_SPECIAL | (BTS_PAUSE & BT_SPECIALMASK);
           return true;
         }
+
       if (ev->data1 <NUMKEYS)
+              
         gamekeydown[ev->data1] = true;
       return true;    // eat key down events
 
@@ -682,15 +690,8 @@ boolean G_Responder (event_t* ev)
       mousebuttons[0] = ev->data1 & 1;
       mousebuttons[1] = ev->data1 & 2;
       mousebuttons[2] = ev->data1 & 4;
-      /*
-       * bmead@surfree.com
-       * Modified by Barry Mead after adding vastly more resolution
-       * to the Mouse Sensitivity Slider in the options menu 1-9-2000
-       * Removed the mouseSensitivity "*4" to allow more low end
-       * sensitivity resolution especially for lsdoom users.
-       */
-      mousex = (ev->data2*(mouseSensitivity_horiz))/10;  /* killough */
-      mousey = (ev->data3*(mouseSensitivity_vert))/10;  /*Mead rm *4 */
+      mousex = (ev->data2*(mouseSensitivity_horiz*4))/10;  // killough
+      mousey = (ev->data3*(mouseSensitivity_vert*4))/10;
       return true;    // eat events
 
     case ev_joystick:
@@ -795,9 +796,10 @@ void G_Ticker (void)
           if ((netgame || demoplayback) && cmd->forwardmove > TURBOTHRESHOLD &&
               !(gametic&31) && ((gametic>>5)&3) == i )
             {
-	      extern char *player_names[];
-	      /* cph - don't use sprintf, use doom_printf */
-              doom_printf ("%s is turbo!", player_names[i]);
+              static char turbomessage[80];
+              extern char *player_names[];
+              sprintf (turbomessage, "%s is turbo!", player_names[i]);
+              players[consoleplayer].message = turbomessage;
             }
 
           if (netgame && !netdemo && !(gametic%ticdup) )
@@ -868,7 +870,6 @@ void G_Ticker (void)
     switch (prevgamestate) {
     case GS_INTERMISSION:
       WI_End();
-    default:
     }
     prevgamestate = gamestate;
   }
@@ -1413,7 +1414,7 @@ void G_DoLoadGame(void)
   int savegame_compatibility = forced_loadgame ? boom_compatibility /* Default to Boom v2.02 */
     : -1;
 
-  G_SaveGameName(name,sizeof(name),savegameslot);
+  G_SaveGameName(name,savegameslot);
 
   gameaction = ga_nothing;
 
@@ -1546,14 +1547,19 @@ void CheckSaveGame(size_t size)
            savegamesize += (size+1023) & ~1023)) + pos;
 }
 
-/* killough 3/22/98: form savegame name in one location
- * (previously code was scattered around in multiple places)
- * cph - Avoid possible buffer overflow problems by passing 
- * size to this function and using snprintf */
+// killough 3/22/98: form savegame name in one location
+// (previously code was scattered around in multiple places)
 
-void G_SaveGameName(char *name, size_t size, int slot)
+void G_SaveGameName(char *name, int slot)
 {
-  snprintf (name, size, "%s/%s%d.dsg", basesavegame, savegamename, slot);
+  // CPhipps - cdrom handling should be done elsewhere
+#ifdef DJGPP
+  // Ty 05/04/98 - use savegamename variable (see d_deh.c)
+  if (M_CheckParm("-cdrom"))
+    sprintf(name, "c:\\doomdata\\%s%d.dsg", savegamename, slot);
+  else
+#endif
+    sprintf (name, "%s/%s%d.dsg", basesavegame, savegamename, slot);
 }
 
 void G_DoSaveGame (void)
@@ -1566,7 +1572,7 @@ void G_DoSaveGame (void)
   gameaction = ga_nothing; // cph - cancel savegame at top of this function, 
     // in case later problems cause a premature exit
 
-  G_SaveGameName(name,sizeof(name),savegameslot);
+  G_SaveGameName(name,savegameslot);
 
   description = savedescription;
 
@@ -2286,7 +2292,7 @@ void doom_printf(const char *s, ...)
   static char msg[MAX_MESSAGE_SIZE];
   va_list v;
   va_start(v,s);
-  vsnprintf(msg,sizeof(msg),s,v);        /* print message in buffer */
+  vsprintf(msg,s,v);                  // print message in buffer
   va_end(v);
   players[consoleplayer].message = msg;  // set new message
 }
@@ -2294,16 +2300,6 @@ void doom_printf(const char *s, ...)
 //----------------------------------------------------------------------------
 //
 // $Log: g_game.c,v $
-// Revision 1.36  2000/03/17 20:50:30  cph
-// Commit mead's improved mouse stuff
-//
-// Revision 1.35  2000/02/26 19:19:51  cph
-// Use doom_printf for turbo warnings; pass buffer size to G_SaveGameName
-//
-// Revision 1.34  1999/10/31 12:38:09  cphipps
-// Add include for i_main.h (for timer stuff)
-// Remove I_BaseTiccmd call, just zeroise new tics
-//
 // Revision 1.33  1999/10/17 09:35:15  cphipps
 // Fixed hanging else(s)
 //
