@@ -1,7 +1,7 @@
 /* Emacs style mode select   -*- C++ -*- 
  *-----------------------------------------------------------------------------
  *
- * $Id: l_video_trans.c,v 1.16 1999/12/13 17:22:43 cphipps Exp $
+ * $Id: l_video_trans.c,v 1.14 1999/10/12 13:01:11 cphipps Exp $
  *
  *  Video mode translation for LxDoom, 
  *   parts from the original linuxdoom i_video.c
@@ -28,10 +28,10 @@
  *-----------------------------------------------------------------------------*/
 
 #ifndef lint
-static const char rcsid[] = "$Id: l_video_trans.c,v 1.16 1999/12/13 17:22:43 cphipps Exp $";
+static const char rcsid[] = "$Id: l_video_trans.c,v 1.14 1999/10/12 13:01:11 cphipps Exp $";
 #endif /* lint */
 
-#ifdef LINUX
+#ifndef LINUX
 
 // Use the standard ffz
 #include <asm/bitops.h>
@@ -54,7 +54,7 @@ static const inline unsigned long ffz(unsigned long x)
 #include "doomtype.h"
 #include "v_video.h"
 #include "i_video.h"
-#include "lprintf.h"
+#include "i_system.h"
 #include "l_video_trans.h"
 #include "z_zone.h"
 #include "m_swap.h"
@@ -249,7 +249,7 @@ static void I_Copyto16Buf(pval* out_buffer, const byte* src)
   } while (--count);
 #else
   asm("xorl %%eax,%%eax ; "
-      ".align 8 ; "
+      ".align 16 ; "
       "0:"
       "movb (%%esi),%%al ; "
       "addl $4,%%esi ; "
@@ -393,7 +393,7 @@ static void I_Copyto32Buf(pval* out_buffer, const byte* src)
   } while (--count);
 #else
   asm("xorl %%eax,%%eax ; "
-      ".align 8 ; " 
+      ".align 16 ; " 
       "0:"
       "movb (%%esi),%%al ; "
       "addl $4,%%esi ; "
@@ -501,12 +501,6 @@ void I_EndImageTranslation(void)
 
 /*
  * $Log: l_video_trans.c,v $
- * Revision 1.16  1999/12/13 17:22:43  cphipps
- * Reduce .align 16's to .align 8's to allow compiling on OpenBSD
- *
- * Revision 1.15  1999/10/31 12:49:44  cphipps
- * Use lprintf.h for I_Error
- *
  * Revision 1.14  1999/10/12 13:01:11  cphipps
  * Changed header to GPL
  *
