@@ -158,7 +158,7 @@ static void W_AddFile(const char *filename, wad_source_t source)
     {
       if (strlen(filename)<=4 ||      // add error check -- killough
 	  strcasecmp(filename+strlen(filename)-4 , ".lmp" ) )
-	I_Error("Error: couldn't open %s\n",filename);  // killough
+//	I_Error("Error: couldn't open %s\n",filename);  // killough
       return;
     }
 
